@@ -197,7 +197,7 @@ class SDK:
             return self._client_protocol.send_file(data, file_target_name)
 
     def get_file(self, remote_file_name, file_target_name):
-        file_bytes = self._client_protocol.get_file(remote_file_name, file_target_name)
+        file_bytes = self._client_protocol.get_file(remote_file_name)
         with open(file_target_name, "wb") as file:
             file.write(file_bytes)
 
